# Flot Examples

Here are some examples for Flot, the Javascript charting library for jQuery:

- Basic example
- Different graph types
- Setting various options and annotating a chart
- Updating graphs with AJAX

Being interactive:

- Turning series on/off
- Rectangular selection support and zooming and zooming with overview
(both with selection plugin)
- Interacting with the data points
- Panning and zooming (with navigation plugin)

Some more esoteric features:

- Plotting time series and visitors per day with zooming and weekends (with selection plugin)
- Dual axis support
- Thresholding the data (with threshold plugin)
- Stacked charts (with stacking plugin)
- Tracking curves with crosshair (with crosshair plugin)
- Plotting prerendered images (with image plugin)